CreationInterpretationCustody

Enum CreationInterpretationCustody 

pub enum CreationInterpretationCustody<A, C>
where A: Address, C: ChildCreationProduct<A, ChildHead>,
{ Routing { input: Option<Creations<CreateChild<A, C>>>, received: Option<ItemSettlement<Creations<CreateChild<A, C>>, Creations<RoutedCreation<A, C>>, ChildNamespaceExhausted, Never>>, }, Children(Vec<(Option<RoutedCreation<A, C>>, Option<ItemSettlement<RoutedCreation<A, C>, <C as ChildCreationProduct<A, ChildHead>>::Result, CreationRejection, Never>>)>), }
Outside custody of the actual routing reply or ordered child attempts. Native causes remain runtime retirement facts, not this normal typed product.

Variants



Routing



Children(Vec<(Option<RoutedCreation<A, C>>, Option<ItemSettlement<RoutedCreation<A, C>, <C as ChildCreationProduct<A, ChildHead>>::Result, CreationRejection, Never>>)>)