CreationSettlement

Enum CreationSettlement 

pub enum CreationSettlement<Requests, Settlements> {
    Settled(Settlements),
    Rejected {
        creations: Requests,
        reason: ChildNamespaceExhausted,
    },
    Corrupt {
        creations: Requests,
        fault: InterpreterFault,
    },
}
Final settlement of the creation leg of one Actions value.

Variants



Settled(Settlements)

The whole batch was routed and every child has an exact settlement.



Rejected

Route preparation rejected the complete unchanged batch.

Fields

creations: Requests


Corrupt

Route preparation corrupted before transferring any request.

Fields

creations: Requests