EventLayer

Enum EventLayer 

pub enum EventLayer<Owned, Inner> {
    Owned(Owned),
    Inner(Inner),
}
One statically owned input lane composed in front of an inner event algebra.

EventLayer is a concrete coproduct, not an erased envelope. Owned is the lane introduced by the current behavior template and Inner preserves the complete event algebra of the wrapped behavior.

Variants



Owned(Owned)



Inner(Inner)