LogicalDeliveryReason

Enum LogicalDeliveryReason 

pub enum LogicalDeliveryReason {
    UnknownAddress,
    ClosedRecipient,
}
One pure communication addressed to a concrete protocol signature.

Protocol identity is not inferred from the payload. Consequently, two protocols with the same address and message types still have distinct delivery types.

ⓘ
struct Queue;
struct Worker;
impl behavior::Protocol for Queue {
    type Addr = behavior::MailAddr;
    type Msg = u8;
}
impl behavior::Protocol for Worker {
    type Addr = behavior::MailAddr;
    type Msg = u8;
}

let worker = behavior::Recipient::<Worker>::global(behavior::MailAddr(1));
let _: behavior::Delivery<Queue> = behavior::Delivery::new(worker, 7);

A destination also fixes its message and address namespaces:

ⓘ
#[derive(Clone, Copy, PartialEq, Eq)]
struct OtherAddr(u64);
impl behavior::Address for OtherAddr {
    type Nonce = u64;
}
struct Worker;
impl behavior::Protocol for Worker {
    type Addr = behavior::MailAddr;
    type Msg = u8;
}
let _ = behavior::Recipient::<Worker>::global(OtherAddr(1));
ⓘ
let worker = behavior::Recipient::<Worker>::global(behavior::MailAddr(1));
let _ = behavior::Delivery::<Worker>::new(worker, "wrong payload");

Exact reason one logical delivery was not accepted.

Variants



UnknownAddress



ClosedRecipient