PoolRejection

Enum PoolRejection 

pub enum PoolRejection {
    BacklogFull,
    AffinityUnavailable,
}
Why a submitted job was not accepted by the pool.

Variants



BacklogFull



AffinityUnavailable

The key’s selected stable slot is unknown or permanently retired.