ReceiveTimeoutError

Enum ReceiveTimeoutError 

pub enum ReceiveTimeoutError<E> {
    Inner(E),
    GenerationExhausted,
}
A controlled receive-timeout failure.

Variants



Inner(E)

The inner fold or timeout reaction failed.



GenerationExhausted

Advancing the timer generation would make a stale delivery live again.

This is detected after the successful continuing inner user fold: the inner state mutation has occurred, but its returned sends and creations are not emitted because the composed transition fails. Bombay behavior folds are not transactional and wrappers cannot roll back inner state.