pub struct ReturnsToEmitter<Input, Path>(/* private fields */);Expand description
An interpreter request whose later Input returns to the emitting actor at
Path, relative to the effect lane that owns the request.