AppendSend

Trait AppendSend 

pub trait AppendSend<Input, Path>: Sized {
    // Required method
    fn append_send(self, input: Input) -> Self;
}
Capability to append one communication at a statically selected lane while preserving every other actor-transition effect.

Required Methods

fn append_send(self, input: Input) -> Self

Append input exactly once and preserve creations and the next verdict.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<A, Ph, Sends, Birth, Input, Path> AppendSend<Input, Path> for Actions<A, Ph, Sends, Birth>
where A: Address, Birth: BirthMode, Sends: SendInput<Input, Path>,