pub trait ChildProduct<A: Address>: ChildProduct + Sized {
type Choice: BirthNodeAppend<Never>;
}Expand description
Closed recursive conversion implemented only by Bombay child products.
Required Associated Types
Sourcetype Choice: BirthNodeAppend<Never>
type Choice: BirthNodeAppend<Never>
Closed sum containing exactly the concrete child behavior types.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.