EventInput

Trait EventInput 

pub trait EventInput<Input>: Sized {
    // Required method
    fn inject(input: Input) -> Self;
}
A statically proven injection of one semantic input into a concrete event sum.

Implementations must select exactly one constructor and preserve input unchanged. Absence of an implementation means that the protocol does not accept that input.

Required Methods

fn inject(input: Input) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<A, M> EventInput<User<A, M>> for User<A, M>

Source

impl<E> EventInput<ChildStopped<<E as UserEvent>::Addr>> for ShutdownProtocol<E>

Source

impl<E> EventInput<ChildStopped<<E as UserEvent>::Addr>> for TimedEvent<E>

Source

impl<E> EventInput<ChildStopped<<E as UserEvent>::Addr>> for WatchEvent<E>

Source

impl<E> EventInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for ShutdownProtocol<E>

Source

impl<E> EventInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for TimedEvent<E>

Source

impl<E> EventInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for WatchEvent<E>

Source

impl<E> EventInput<PeerStopped<<E as UserEvent>::Addr>> for ProxyEvent<E>

Source

impl<E> EventInput<PeerStopped<<E as UserEvent>::Addr>> for ShutdownProtocol<E>

Source

impl<E> EventInput<PeerStopped<<E as UserEvent>::Addr>> for SupervisionEvent<E>

Source

impl<E> EventInput<PeerStopped<<E as UserEvent>::Addr>> for TimedEvent<E>

Source

impl<E> EventInput<ShutdownRequested> for ProxyEvent<E>

Source

impl<E> EventInput<ShutdownRequested> for SupervisionEvent<E>

Source

impl<E> EventInput<ShutdownRequested> for TimedEvent<E>

Source

impl<E> EventInput<ShutdownRequested> for WatchEvent<E>

Source

impl<E> EventInput<TimerElapsed> for ProxyEvent<E>

Source

impl<E> EventInput<TimerElapsed> for ShutdownProtocol<E>

Source

impl<E> EventInput<TimerElapsed> for SupervisionEvent<E>

Source

impl<E> EventInput<TimerElapsed> for WatchEvent<E>

Source

impl<E> EventInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for ProxyEvent<E>

Source

impl<E> EventInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for ShutdownProtocol<E>

Source

impl<E> EventInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for TimedEvent<E>

Source

impl<E> EventInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for WatchEvent<E>

Source

impl<E> EventInput<WorkerStopped<<E as UserEvent>::Addr>> for ProxyEvent<E>

Source

impl<E> EventInput<WorkerStopped<<E as UserEvent>::Addr>> for ShutdownProtocol<E>

Source

impl<E> EventInput<WorkerStopped<<E as UserEvent>::Addr>> for TimedEvent<E>

Source

impl<E> EventInput<WorkerStopped<<E as UserEvent>::Addr>> for WatchEvent<E>

Source

impl<E: UserEvent> EventInput<ChildStopped<<E as UserEvent>::Addr>> for ProxyEvent<E>

Source

impl<E: UserEvent> EventInput<ChildStopped<<E as UserEvent>::Addr>> for SupervisionEvent<E>

Source

impl<E: UserEvent> EventInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for ProxyEvent<E>

Source

impl<E: UserEvent> EventInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for SupervisionEvent<E>

Source

impl<E: UserEvent> EventInput<PeerStopped<<E as UserEvent>::Addr>> for WatchEvent<E>

Source

impl<E: UserEvent> EventInput<ShutdownRequested> for ShutdownProtocol<E>

Source

impl<E: UserEvent> EventInput<TimerElapsed> for TimedEvent<E>

Source

impl<E: UserEvent> EventInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for SupervisionEvent<E>

Source

impl<E: UserEvent> EventInput<WorkerStopped<<E as UserEvent>::Addr>> for SupervisionEvent<E>