InterpretCreations

Trait InterpretCreations 

pub trait InterpretCreations<A, Interpreter, RootEvent, Path>: CreationSettlements<A>
where A: Address,
{ // Required method fn interpret_creations( progress: &mut Option<InterpretationProgress<Creations<CreateChild<A, Self::Child>>, Self::InterpretationCustody, Self::Settlements>>, interpreter: &mut Interpreter, ) -> impl Future<Output = ()> + Send; }
Generic interpretation of the one creation leg selected by a birth mode.

NoBirths needs no runtime capability. Births<C> performs one real batch route attempt followed by independent child establishment in declared order.

Required Methods

fn interpret_creations( progress: &mut Option<InterpretationProgress<Creations<CreateChild<A, Self::Child>>, Self::InterpretationCustody, Self::Settlements>>, interpreter: &mut Interpreter, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<A, C, Interpreter, RootEvent, Path> InterpretCreations<A, Interpreter, RootEvent, Path> for Births<C>
where A: Address, A::Nonce: Send, C: ChildCreationProduct<A, ChildHead> + DispatchBirth<A, Interpreter> + Send, <C as ChildCreationProduct<A, ChildHead>>::Result: Send, Interpreter: InterpretItem<Creations<CreateChild<A, C>>, RootEvent, Path> + Send,

Source

impl<A, C, Interpreter, RootEvent, Path> InterpretCreations<A, Interpreter, RootEvent, Path> for RetirementBirths<C>
where A: Address, C: ChildCreationProduct<A, ChildHead>, Births<C>: BirthMode<Child = C> + InterpretCreations<A, Interpreter, RootEvent, Path>, Creations<CreateChild<A, C>>: Send, <Births<C> as CreationSettlements<A>>::InterpretationCustody: Send, <Births<C> as CreationSettlements<A>>::Settlements: Send, Interpreter: Send,

Source

impl<A, Interpreter, RootEvent, Path> InterpretCreations<A, Interpreter, RootEvent, Path> for NoBirths