pub type ResolvedChildPosition<Emitter, Occurrence> = <Emitter as ResolveChildOccurrence<Occurrence>>::Position;Expand description
Structural birth position resolved from Occurrence for the running
Emitter.
pub type ResolvedChildPosition<Emitter, Occurrence> = <Emitter as ResolveChildOccurrence<Occurrence>>::Position;Structural birth position resolved from Occurrence for the running
Emitter.