pub enum CreationInterpretationCustody<A, C>{
Routing {
input: Option<Creations<CreateChild<A, C>>>,
received: Option<ItemSettlement<Creations<CreateChild<A, C>>, Creations<RoutedCreation<A, C>>, ChildNamespaceExhausted, Never>>,
},
Children(Vec<(Option<RoutedCreation<A, C>>, Option<ItemSettlement<RoutedCreation<A, C>, <C as ChildCreationProduct<A, ChildHead>>::Result, CreationRejection, Never>>)>),
}Expand description
Outside custody of the actual routing reply or ordered child attempts. Native causes remain runtime retirement facts, not this normal typed product.
Variants
Routing
Fields

input: Option<Creations<CreateChild<A, C>>>
received: Option<ItemSettlement<Creations<CreateChild<A, C>>, Creations<RoutedCreation<A, C>>, ChildNamespaceExhausted, Never>>Children(Vec<(Option<RoutedCreation<A, C>>, Option<ItemSettlement<RoutedCreation<A, C>, <C as ChildCreationProduct<A, ChildHead>>::Result, CreationRejection, Never>>)>)