pub struct CommittedChild<C, Occurrence>{ /* private fields */ }Expand description
One committed fresh child with its creator-local provenance and exact installed actor. The occurrence distinguishes equal child behaviors in distinct static positions; it is not an actor identity or runtime route.
Implementations
Sourceimpl<C, Occurrence> CommittedChild<C, Occurrence>
impl<C, Occurrence> CommittedChild<C, Occurrence>
Sourcepub const fn new(
id: CreationId,
kind: CreationKind,
actor: EstablishedActor<C>,
) -> Self
pub const fn new( id: CreationId, kind: CreationKind, actor: EstablishedActor<C>, ) -> Self
Record an already committed fresh installation. This does not install an actor; only a successful interpreter installation may issue its runtime-owned actor value.
pub const fn id(&self) -> CreationId
pub const fn kind(&self) -> CreationKind
pub fn actor(&self) -> EstablishedActor<C>
pub fn into_parts(self) -> (CreationId, CreationKind, EstablishedActor<C>)