pub struct SendLayer<Owned, Inner> {
pub owned: Owned,
pub inner: Inner,
}Expand description
Send effects introduced by one wrapper around inner send effects.
owned contains effects introduced by the current behavior layer and
inner contains effects of the wrapped interaction. The structural
SendsFor implementation is the composition law:
Event' = OwnedEvent + InnerEvent
Effects' = OwnedEffects × InnerEffectsOwned return to the emitters target Event'; inner return to the emitters target
InnerEvent and are therefore lifted through the same Inner injection.
Established actor, child, and ancestor destinations are unaffected because
they are not return to the emitters.
Fields
owned: Ownedinner: InnerImplementations