pub trait AppendSend<Input, Path>: Sized {
// Required method
fn append_send(self, input: Input) -> Self;
}Expand description
Capability to append one communication at a statically selected lane while preserving every other actor-transition effect.
Required Methods
Sourcefn append_send(self, input: Input) -> Self
fn append_send(self, input: Input) -> Self
Append input exactly once and preserve creations and the next verdict.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.