pub trait InterpretCreations<A, Interpreter, RootEvent, Path>: CreationSettlements<A>where
A: Address,{
// Required method
fn interpret_creations(
progress: &mut Option<InterpretationProgress<Creations<CreateChild<A, Self::Child>>, Self::InterpretationCustody, Self::Settlements>>,
interpreter: &mut Interpreter,
) -> impl Future<Output = ()> + Send;
}Expand description
Generic interpretation of the one creation leg selected by a birth mode.
NoBirths needs no runtime capability. Births<C> performs one real batch
route attempt followed by independent child establishment in declared order.
Required Methods
fn interpret_creations( progress: &mut Option<InterpretationProgress<Creations<CreateChild<A, Self::Child>>, Self::InterpretationCustody, Self::Settlements>>, interpreter: &mut Interpreter, ) -> impl Future<Output = ()> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.